@@ -1,5 +1,5 @@
 # These functions are
-# Copyright (C) 1998-2018 T.W. Yee, University of Auckland.
+# Copyright (C) 1998-2020 T.W. Yee, University of Auckland.
 # All rights reserved.
 
 
@@ -55,7 +55,8 @@
 
 
   if (Rank == 0 && !has.intercept)
-    warning("probably 'has.intercept == TRUE' is better for a rank-0 model")
+    warning("probably 'has.intercept == TRUE' is better for ",
+            "a rank-0 model")
 
 
 
@@ -119,19 +120,24 @@
 
 
   .rcim.df <-
-    if (!noroweffects) data.frame("Row.2" = I.col(2, nrow(y))) else  # See below
-    if (!nocoleffects) data.frame("Col.2" = I.col(2, nrow(y))) else  # See below
-    stop("at least one of 'noroweffects' and 'nocoleffects' must be FALSE")
+    if (!noroweffects)
+      data.frame("Row.2" = I.col(2, nrow(y))) else  # See below
+    if (!nocoleffects)
+      data.frame("Col.2" = I.col(2, nrow(y))) else  # See below
+      stop("at least one of 'noroweffects' and 'nocoleffects' ",
+           "must be FALSE")
 
 
-  min.row.val <- rindex[1]  # == min(rindex) since it is sorted # Usually 2
-  min.col.val <- cindex[1]  # == min(cindex) since it is sorted # Usually 2
+  min.row.val <- rindex[1]  # == min(rindex) since its sorted # Usually 2
+  min.col.val <- cindex[1]  # == min(cindex) since its sorted # Usually 2
   if (!noroweffects) {
-    colnames( .rcim.df ) <- paste(rprefix, as.character(min.row.val),  # "2",
-                                  sep = "")  # Overwrite "Row.2"
+    colnames( .rcim.df ) <-
+      paste(rprefix, as.character(min.row.val),  # "2",
+            sep = "")  # Overwrite "Row.2"
   } else if (!nocoleffects) {
-    colnames( .rcim.df ) <- paste(cprefix, as.character(min.col.val),  # "2",
-                                  sep = "")  # Overwrite "Col.2"
+    colnames( .rcim.df ) <-
+      paste(cprefix, as.character(min.col.val),  # "2",
+            sep = "")  # Overwrite "Col.2"
   }
 
 
@@ -602,15 +608,15 @@ setMethod("plot", "rcim",
   ind1 <- if (is.character(roffset))
              which(rownames(mat) == roffset) else
                    if (is.numeric(roffset)) roffset + 1 else
-                     stop("argument 'roffset' not matched (character). ",
-                           "It must be numeric, ",
+                     stop("argument 'roffset' not matched (character).",
+                           " It must be numeric, ",
                            "else character and match the ",
                            "row names of the response")
   ind2 <- if (is.character(coffset))
              which(colnames(mat) == coffset) else
                    if (is.numeric(coffset)) coffset + 1 else
-                     stop("argument 'coffset' not matched (character). ",
-                           "It must be numeric, ",
+                     stop("argument 'coffset' not matched (character).",
+                           " It must be numeric, ",
                            "else character and match the ",
                            "column names of the response")
 
@@ -686,12 +692,12 @@ Confint.rrnb <- function(rrnb2, level = 0.95) {
   if (rrnb2@misc$M != 2)
     stop("argument 'rrnb2' does not have M = 2")
 
-  if (!all(rrnb2@misc$link == "loge"))
+  if (!all(rrnb2@misc$link == "loglink"))
     stop("argument 'rrnb2' does not have log links for both parameters")
 
-  a21.hat <- (Coef(rrnb2)@A)["loge(size)", 1]
-  beta11.hat <- Coef(rrnb2)@B1["(Intercept)", "loge(mu)"]
-  beta21.hat <- Coef(rrnb2)@B1["(Intercept)", "loge(size)"]
+  a21.hat <- (Coef(rrnb2)@A)["loglink(size)", 1]
+  beta11.hat <- Coef(rrnb2)@B1["(Intercept)", "loglink(mu)"]
+  beta21.hat <- Coef(rrnb2)@B1["(Intercept)", "loglink(size)"]
   delta1.hat <- exp(a21.hat * beta11.hat - beta21.hat)
   delta2.hat <- 2 - a21.hat
 
@@ -736,24 +742,22 @@ Confint.nb1 <- function(nb1, level = 0.95) {
   if (nb1@misc$M != 2)
     stop("argument 'nb1' does not have M = 2")
 
-  if (!all(nb1@misc$link == "loge"))
+  if (!all(nb1@misc$link == "loglink"))
     stop("argument 'nb1' does not have log links for both parameters")
 
   cnb1 <- coefficients(as(nb1, "vglm"), matrix = TRUE)
-  mydiff <- (cnb1["(Intercept)", "loge(size)"] -
-             cnb1["(Intercept)", "loge(mu)"])
+  mydiff <- (cnb1["(Intercept)", "loglink(size)"] -
+             cnb1["(Intercept)", "loglink(mu)"])
   delta0.hat <- exp(mydiff)
   (phi0.hat <- 1 + 1 / delta0.hat)  # MLE of phi0
 
 
-
-
   myvcov <- vcov(as(nb1, "vglm"))  # Not great; improve this!
 
 
 
   myvec <- cbind(c(-1, 1, rep_len(0, nrow(myvcov) - 2)))
-  (se.mydiff <- sqrt(t(myvec) %*%  myvcov %*%  myvec))
+  se.mydiff <- c(sqrt(t(myvec) %*% myvcov %*% myvec))  # c() to drop the 2-D
 
   ci.mydiff <- mydiff + c(-1, 1) * qnorm(1 - (1 - level)/2) * se.mydiff
 
