@@ -1,22 +1,22 @@
 alcoff <-
-structure(list(Monday = c(121L, 97L, 60L, 55L, 25L, 19L, 13L, 
+structure(list(Mon = c(121L, 97L, 60L, 55L, 25L, 19L, 13L, 
 20L, 5L, 7L, 7L, 8L, 10L, 9L, 22L, 39L, 28L, 46L, 53L, 74L, 74L, 
-84L, 90L, 110L), Tuesday = c(98L, 92L, 69L, 60L, 38L, 10L, 9L, 
+84L, 90L, 110L), Tue = c(98L, 92L, 69L, 60L, 38L, 10L, 9L, 
 6L, 8L, 8L, 13L, 10L, 13L, 26L, 41L, 48L, 48L, 59L, 100L, 119L, 
-135L, 154L, 143L, 169L), Wednesday = c(165L, 157L, 107L, 75L, 
+135L, 154L, 143L, 169L), Wed = c(165L, 157L, 107L, 75L, 
 48L, 20L, 9L, 9L, 12L, 14L, 20L, 20L, 8L, 32L, 31L, 62L, 71L, 
-98L, 117L, 155L, 283L, 326L, 345L, 363L), Thursday = c(324L, 
+98L, 117L, 155L, 283L, 326L, 345L, 363L), Thu = c(324L, 
 278L, 229L, 238L, 145L, 56L, 55L, 42L, 29L, 28L, 36L, 32L, 39L, 
 37L, 46L, 69L, 85L, 141L, 185L, 289L, 508L, 610L, 765L, 899L), 
-    Friday = c(827L, 619L, 410L, 401L, 223L, 139L, 70L, 40L, 
+    Fri = c(827L, 619L, 410L, 401L, 223L, 139L, 70L, 40L, 
     40L, 38L, 38L, 27L, 37L, 27L, 42L, 59L, 55L, 136L, 223L, 
-    335L, 591L, 866L, 976L, 1265L), Saturday = c(1379L, 1327L, 
+    335L, 591L, 866L, 976L, 1265L), Sat = c(1379L, 1327L, 
     979L, 693L, 346L, 188L, 155L, 160L, 79L, 44L, 52L, 44L, 73L, 
     41L, 58L, 75L, 96L, 154L, 236L, 337L, 490L, 754L, 1026L, 
-    1179L), Sunday = c(1332L, 1356L, 1011L, 718L, 410L, 287L, 
+    1179L), Sun = c(1332L, 1356L, 1011L, 718L, 410L, 287L, 
     213L, 200L, 96L, 58L, 69L, 39L, 59L, 45L, 53L, 70L, 95L, 
-    130L, 121L, 146L, 166L, 131L, 114L, 159L)), .Names = c("Monday", 
-"Tuesday", "Wednesday", "Thursday", "Friday", "Saturday", "Sunday"
+    130L, 121L, 146L, 166L, 131L, 114L, 159L)), .Names = c("Mon", 
+"Tue", "Wed", "Thu", "Fri", "Sat", "Sun"
 ), class = "data.frame", row.names = c("0", "1", "2", "3", "4", 
 "5", "6", "7", "8", "9", "10", "11", "12", "13", "14", "15", 
 "16", "17", "18", "19", "20", "21", "22", "23"))
